@@ -4,7 +4,7 @@ import logging
 import os
 import random
 import sys
-from typing import Any, Callable, Dict, Union
+from typing import Any, Callable, Dict, Iterable, Optional, TypeVar, Union
 
 import jmespath
 
@@ -12,13 +12,15 @@ from ..shared import constants
 from ..shared.functions import resolve_env_var_choice, resolve_truthy_env_var_choice
 from .exceptions import InvalidLoggerSamplingRateError
 from .filters import SuppressFilter
-from .formatter import JsonFormatter
+from .formatter import BasePowertoolsFormatter, LambdaPowertoolsFormatter
 from .lambda_context import build_lambda_context_model
 
 logger = logging.getLogger(__name__)
 
 is_cold_start = True
 
+PowertoolsFormatter = TypeVar("PowertoolsFormatter", bound=BasePowertoolsFormatter)
+
 
 def _is_cold_start() -> bool:
     """Verifies whether is cold start
@@ -42,6 +44,7 @@ def _is_cold_start() -> bool:
 # so we need to return to subclassing removed in #97
 # All methods/properties continue to be proxied to inner logger
 # https://github.com/awslabs/aws-lambda-powertools-python/issues/107
+# noinspection PyRedeclaration
 class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
     """Creates and setups a logger to format statements in JSON.
 
@@ -69,6 +72,28 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         sample rate for debug calls within execution context defaults to 0.0
     stream: sys.stdout, optional
         valid output for a logging stream, by default sys.stdout
+    logger_formatter: PowertoolsFormatter, optional
+        custom logging formatter that implements PowertoolsFormatter
+    logger_handler: logging.Handler, optional
+        custom logging handler e.g. logging.FileHandler("file.log")
+
+    Parameters propagated to LambdaPowertoolsFormatter
+    ---------------------------------------------
+    datefmt: str, optional
+        String directives (strftime) to format log timestamp, by default it uses RFC 3339.
+    json_serializer : Callable, optional
+        function to serialize `obj` to a JSON formatted `str`, by default json.dumps
+    json_deserializer : Callable, optional
+        function to deserialize `str`, `bytes`, bytearray` containing a JSON document to a Python `obj`,
+        by default json.loads
+    json_default : Callable, optional
+        function to coerce unserializable values, by default `str()`
+
+        Only used when no custom formatter is set
+    utc : bool, optional
+        set logging timestamp to UTC, by default False to continue to use local time as per stdlib
+    log_record_order : list, optional
+        set order of log keys when logging, by default ["level", "location", "message", "timestamp"]
 
     Example
     -------
@@ -96,7 +121,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         >>> logger = Logger(service="payment")
         >>>
         >>> def handler(event, context):
-                logger.structure_logs(append=True, payment_id=event["payment_id"])
+                logger.append_keys(payment_id=event["payment_id"])
                 logger.info("Hello")
 
     **Create child Logger using logging inheritance via child param**
@@ -110,6 +135,30 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         >>> from aws_lambda_powertools import Logger
         >>> logger = Logger(service="payment", child=True)
 
+    **Logging in UTC timezone**
+
+        >>> # app.py
+        >>> import logging
+        >>> from aws_lambda_powertools import Logger
+        >>>
+        >>> logger = Logger(service="payment", utc=True)
+
+    **Brings message as the first key in log statements**
+
+        >>> # app.py
+        >>> import logging
+        >>> from aws_lambda_powertools import Logger
+        >>>
+        >>> logger = Logger(service="payment", log_record_order=["message"])
+
+    **Logging to a file instead of standard output for testing**
+
+        >>> # app.py
+        >>> import logging
+        >>> from aws_lambda_powertools import Logger
+        >>>
+        >>> logger = Logger(service="payment", logger_handler=logging.FileHandler("log.json"))
+
     Raises
     ------
     InvalidLoggerSamplingRateError
@@ -123,22 +172,26 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         child: bool = False,
         sampling_rate: float = None,
         stream: sys.stdout = None,
+        logger_formatter: Optional[PowertoolsFormatter] = None,
+        logger_handler: Optional[logging.Handler] = None,
         **kwargs,
     ):
         self.service = resolve_env_var_choice(
             choice=service, env=os.getenv(constants.SERVICE_NAME_ENV, "service_undefined")
         )
         self.sampling_rate = resolve_env_var_choice(
-            choice=sampling_rate, env=os.getenv(constants.LOGGER_LOG_SAMPLING_RATE, 0.0)
+            choice=sampling_rate, env=os.getenv(constants.LOGGER_LOG_SAMPLING_RATE)
         )
+        self.child = child
+        self.logger_formatter = logger_formatter
+        self.logger_handler = logger_handler or logging.StreamHandler(stream)
+        self.log_level = self._get_log_level(level)
         self._is_deduplication_disabled = resolve_truthy_env_var_choice(
             env=os.getenv(constants.LOGGER_LOG_DEDUPLICATION_ENV, "false")
         )
-        self.log_level = self._get_log_level(level)
-        self.child = child
-        self._handler = logging.StreamHandler(stream) if stream is not None else logging.StreamHandler(sys.stdout)
         self._default_log_keys = {"service": self.service, "sampling_rate": self.sampling_rate}
         self._logger = self._get_logger()
+
         self._init_logger(**kwargs)
 
     def __getattr__(self, name):
@@ -147,7 +200,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         return getattr(self._logger, name)
 
     def _get_logger(self):
-        """ Returns a Logger named {self.service}, or {self.service.filename} for child loggers"""
+        """Returns a Logger named {self.service}, or {self.service.filename} for child loggers"""
         logger_name = self.service
         if self.child:
             logger_name = f"{self.service}.{self._get_caller_filename()}"
@@ -168,7 +221,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
         self._configure_sampling()
         self._logger.setLevel(self.log_level)
-        self._logger.addHandler(self._handler)
+        self._logger.addHandler(self.logger_handler)
         self.structure_logs(**kwargs)
 
         # Pytest Live Log feature duplicates log records for colored output
@@ -207,12 +260,18 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
             )
 
     def inject_lambda_context(
-        self, lambda_handler: Callable[[Dict, Any], Any] = None, log_event: bool = None, correlation_id_path: str = None
+        self,
+        lambda_handler: Callable[[Dict, Any], Any] = None,
+        log_event: bool = None,
+        correlation_id_path: str = None,
+        clear_state: bool = False,
     ):
         """Decorator to capture Lambda contextual info and inject into logger
 
         Parameters
         ----------
+        clear_state : bool, optional
+            Instructs logger to remove any custom keys previously added
         lambda_handler : Callable
             Method to inject the lambda context
         log_event : bool, optional
@@ -258,7 +317,10 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         if lambda_handler is None:
             logger.debug("Decorator called with parameters")
             return functools.partial(
-                self.inject_lambda_context, log_event=log_event, correlation_id_path=correlation_id_path
+                self.inject_lambda_context,
+                log_event=log_event,
+                correlation_id_path=correlation_id_path,
+                clear_state=clear_state,
             )
 
         log_event = resolve_truthy_env_var_choice(
@@ -269,7 +331,11 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         def decorate(event, context):
             lambda_context = build_lambda_context_model(context)
             cold_start = _is_cold_start()
-            self.structure_logs(append=True, cold_start=cold_start, **lambda_context.__dict__)
+
+            if clear_state:
+                self.structure_logs(cold_start=cold_start, **lambda_context.__dict__)
+            else:
+                self.append_keys(cold_start=cold_start, **lambda_context.__dict__)
 
             if correlation_id_path:
                 self.set_correlation_id(jmespath.search(correlation_id_path, event))
@@ -282,30 +348,44 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
         return decorate
 
-    def structure_logs(self, append: bool = False, **kwargs):
+    def append_keys(self, **additional_keys):
+        self.registered_formatter.append_keys(**additional_keys)
+
+    def remove_keys(self, keys: Iterable[str]):
+        self.registered_formatter.remove_keys(keys)
+
+    @property
+    def registered_handler(self) -> logging.Handler:
+        """Convenience property to access logger handler"""
+        handlers = self._logger.parent.handlers if self.child else self._logger.handlers
+        return handlers[0]
+
+    @property
+    def registered_formatter(self) -> Optional[PowertoolsFormatter]:
+        """Convenience property to access logger formatter"""
+        return self.registered_handler.formatter
+
+    def structure_logs(self, append: bool = False, **keys):
         """Sets logging formatting to JSON.
 
         Optionally, it can append keyword arguments
-        to an existing logger so it is available
-        across future log statements.
+        to an existing logger so it is available across future log statements.
 
         Last keyword argument and value wins if duplicated.
 
         Parameters
         ----------
         append : bool, optional
-            [description], by default False
+            append keys provided to logger formatter, by default False
         """
 
-        # Child loggers don't have handlers attached, use its parent handlers
-        handlers = self._logger.parent.handlers if self.child else self._logger.handlers
-        for handler in handlers:
-            if append:
-                # Update existing formatter in an existing logger handler
-                handler.formatter.update_formatter(**kwargs)
-            else:
-                # Set a new formatter for a logger handler
-                handler.setFormatter(JsonFormatter(**self._default_log_keys, **kwargs))
+        if append:
+            # Maintenance: Add deprecation warning for major version. Refer to append_keys() when docs are updated
+            self.append_keys(**keys)
+        else:
+            log_keys = {**self._default_log_keys, **keys}
+            formatter = self.logger_formatter or LambdaPowertoolsFormatter(**log_keys)
+            self.registered_handler.setFormatter(formatter)
 
     def set_correlation_id(self, value: str):
         """Sets the correlation_id in the logging json
@@ -315,15 +395,15 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
         value : str
             Value for the correlation id
         """
-        self.structure_logs(append=True, correlation_id=value)
+        self.append_keys(correlation_id=value)
 
     @staticmethod
-    def _get_log_level(level: Union[str, int]) -> Union[str, int]:
-        """ Returns preferred log level set by the customer in upper case """
+    def _get_log_level(level: Union[str, int, None]) -> Union[str, int]:
+        """Returns preferred log level set by the customer in upper case"""
         if isinstance(level, int):
             return level
 
-        log_level: str = level or os.getenv("LOG_LEVEL")
+        log_level: Optional[str] = level or os.getenv("LOG_LEVEL")
         if log_level is None:
             return logging.INFO
 
@@ -331,7 +411,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
     @staticmethod
     def _get_caller_filename():
-        """ Return caller filename by finding the caller frame """
+        """Return caller filename by finding the caller frame"""
         # Current frame         => _get_logger()
         # Previous frame        => logger.py
         # Before previous frame => Caller
