@@ -164,7 +164,7 @@ class APIGatewayEventRequestContext(DictWrapper):
 
     @property
     def stage(self) -> str:
-        """The deployment stage of the API request """
+        """The deployment stage of the API request"""
         return self["requestContext"]["stage"]
 
     @property
@@ -195,6 +195,11 @@ class APIGatewayEventRequestContext(DictWrapper):
         """The selected route key."""
         return self["requestContext"].get("routeKey")
 
+    @property
+    def operation_name(self) -> Optional[str]:
+        """The name of the operation being performed"""
+        return self["requestContext"].get("operationName")
+
 
 class APIGatewayProxyEvent(BaseProxyEvent):
     """AWS Lambda proxy V1
@@ -212,15 +217,6 @@ class APIGatewayProxyEvent(BaseProxyEvent):
     def resource(self) -> str:
         return self["resource"]
 
-    @property
-    def path(self) -> str:
-        return self["path"]
-
-    @property
-    def http_method(self) -> str:
-        """The HTTP method used. Valid values include: DELETE, GET, HEAD, OPTIONS, PATCH, POST, and PUT."""
-        return self["httpMethod"]
-
     @property
     def multi_value_headers(self) -> Dict[str, List[str]]:
         return self["multiValueHeaders"]
@@ -356,7 +352,7 @@ class RequestContextV2(DictWrapper):
 
     @property
     def domain_name(self) -> str:
-        """A domain name """
+        """A domain name"""
         return self["requestContext"]["domainName"]
 
     @property
@@ -379,7 +375,7 @@ class RequestContextV2(DictWrapper):
 
     @property
     def stage(self) -> str:
-        """The deployment stage of the API request """
+        """The deployment stage of the API request"""
         return self["requestContext"]["stage"]
 
     @property
@@ -441,3 +437,12 @@ class APIGatewayProxyEventV2(BaseProxyEvent):
     @property
     def stage_variables(self) -> Optional[Dict[str, str]]:
         return self.get("stageVariables")
+
+    @property
+    def path(self) -> str:
+        return self.raw_path
+
+    @property
+    def http_method(self) -> str:
+        """The HTTP method used. Valid values include: DELETE, GET, HEAD, OPTIONS, PATCH, POST, and PUT."""
+        return self.request_context.http.method
