@@ -1,3 +1,5 @@
+import base64
+import json
 from typing import Any, Dict, Optional
 
 
@@ -25,7 +27,9 @@ class DictWrapper:
         return self._data
 
 
-def get_header_value(headers: Dict[str, str], name: str, default_value: str, case_sensitive: bool) -> Optional[str]:
+def get_header_value(
+    headers: Dict[str, str], name: str, default_value: Optional[str], case_sensitive: Optional[bool]
+) -> Optional[str]:
     """Get header value by name"""
     if case_sensitive:
         return headers.get(name, default_value)
@@ -55,8 +59,31 @@ class BaseProxyEvent(DictWrapper):
 
     @property
     def body(self) -> Optional[str]:
+        """Submitted body of the request as a string"""
         return self.get("body")
 
+    @property
+    def json_body(self) -> Any:
+        """Parses the submitted body as json"""
+        return json.loads(self["body"])
+
+    @property
+    def decoded_body(self) -> str:
+        """Dynamically base64 decode body as a str"""
+        body: str = self["body"]
+        if self.is_base64_encoded:
+            return base64.b64decode(body.encode()).decode()
+        return body
+
+    @property
+    def path(self) -> str:
+        return self["path"]
+
+    @property
+    def http_method(self) -> str:
+        """The HTTP method used. Valid values include: DELETE, GET, HEAD, OPTIONS, PATCH, POST, and PUT."""
+        return self["httpMethod"]
+
     def get_query_string_value(self, name: str, default_value: Optional[str] = None) -> Optional[str]:
         """Get query string value by name
 
