@@ -40,7 +40,7 @@ class DataRecord:
         idempotency_key,
         status: str = "",
         expiry_timestamp: int = None,
-        response_data: str = "",
+        response_data: Optional[str] = "",
         payload_hash: str = None,
     ) -> None:
         """
@@ -110,7 +110,7 @@ class BasePersistenceLayer(ABC):
     """
 
     def __init__(self):
-        """Initialize the defaults """
+        """Initialize the defaults"""
         self.configured = False
         self.event_key_jmespath: Optional[str] = None
         self.event_key_compiled_jmespath = None
@@ -224,6 +224,7 @@ class BasePersistenceLayer(ABC):
             Hashed representation of the provided data
 
         """
+        data = getattr(data, "raw_event", data)  # could be a data class depending on decorator order
         hashed_data = self.hash_function(json.dumps(data, cls=Encoder).encode())
         return hashed_data.hexdigest()
 
