@@ -132,8 +132,8 @@ def validator(
 
 
 def validate(
-    event: Dict,
-    schema: Dict = None,
+    event: Any,
+    schema: Dict,
     formats: Optional[Dict] = None,
     envelope: str = None,
     jmespath_options: Dict = None,
